@@ -1,10 +1,10 @@
-from operations_with_objects.operations_with_objects import OperationsWithObjects
-from operations_with_objects.system_object import SystemObject
-from quick_resto_api import QuickRestoApi
-from quick_resto_objects.modules.warehouse.businessman import Businessman
-from quick_resto_objects.modules.warehouse.natural_person import NaturalPerson
-from quick_resto_objects.modules.warehouse.organization import Organization
-from quick_resto_objects.modules.warehouse.provider_group import ProviderGroup
+from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
+from quick_resto_API.operations_with_objects.system_object import SystemObject
+from quick_resto_API.quick_resto_api import QuickRestoApi
+from quick_resto_API.quick_resto_objects.modules.warehouse.businessman import Businessman
+from quick_resto_API.quick_resto_objects.modules.warehouse.natural_person import NaturalPerson
+from quick_resto_API.quick_resto_objects.modules.warehouse.organization import Organization
+from quick_resto_API.quick_resto_objects.modules.warehouse.provider_group import ProviderGroup
 
 class ProvidersOperations(SystemObject):
     def __init__(self, api: QuickRestoApi):
