@@ -18,9 +18,8 @@ StrToTypeDiscount = {
     TypeDiscount.PERCENT.value: TypeDiscount.PERCENT,
 }
 
-
 def convert_str_to_type_discount(value: str) -> TypeDiscount:
-    if value in TypeDiscount.keys():
+    if value in StrToTypeDiscount.keys():
         return TypeDiscount[value]
 
     return TypeDiscount.NONE
